SystemOrganization addCategory: #Project!

Object subclass: #Administrator
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Project'!

Object subclass: #Course
	instanceVariableNames: 'id name topic subjectList userList public ownerList'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Project'!

!Course commentStamp: 'RFG 5/2/2013 11:43' prior: 0!
Represents a course in the system.!

!Course methodsFor: 'getters' stamp: 'RFG 5/2/2013 13:09'!
id
	"Returns the id of the course."

	^id.! !

!Course methodsFor: 'setters' stamp: 'RFG 5/2/2013 13:13'!
id: anID
	"Sets the ID of the Course"

	self.id := anID.! !

!Course methodsFor: 'getters' stamp: 'RFG 5/2/2013 13:07'!
name
	"Returns the name of the object."

	^(name).! !

!Course methodsFor: 'setters' stamp: 'RFG 5/2/2013 13:02'!
name: aName
	"Sets the name of the course"

	 self.name := aName.! !

!Course methodsFor: 'init' stamp: 'RFG 5/3/2013 11:08'!
new: cid named: aName onTopic: aTopic
	"Creates a new course with the given ID and name"
	
	| course |
	course := Course new.
	course id: cid.
	course name: aName.
	course topic: aTopic.
	^course.! !

!Course methodsFor: 'getters' stamp: 'RFG 5/2/2013 13:12'!
topic
	"Topic of the course"

	^topic.! !

!Course methodsFor: 'setters' stamp: 'RFG 5/2/2013 13:02'!
topic: aTopic
	"Sets the topic of the course"

	self.topic := aTopic.! !

Object subclass: #Group
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Project'!

Object subclass: #Lecture
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Project'!

Object subclass: #Moderator
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Project'!

Object subclass: #Subject
	instanceVariableNames: 'id name creator ownerList'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Project'!

!Subject commentStamp: 'RFG 5/6/2013 15:55' prior: 0!
Represents a Subject in the system.!

!Subject methodsFor: 'accessing' stamp: 'RFG 5/6/2013 16:00'!
id
	"Returns the id of the subject."

	^id.! !

!Subject methodsFor: 'accessing' stamp: 'RFG 5/6/2013 15:57'!
id: anID
	"Sets the id of the subject."

	id := anID.! !

Object subclass: #System
	instanceVariableNames: ''
	classVariableNames: 'TopicTable UserTable'
	poolDictionaries: ''
	category: 'Project'!

!System commentStamp: 'RFG 5/2/2013 13:21' prior: 0!
The main class representing the own system.!

!System class methodsFor: 'initialization' stamp: 'RFG 5/3/2013 19:59'!
create
	"Creates an empty system."! !

!System methodsFor: 'accessing' stamp: 'RFG 5/3/2013 20:54'!
TopicTable
	"Returns the dictionary with all topics."

	^TopicTable.! !

!System methodsFor: 'accessing' stamp: 'RFG 5/3/2013 20:54'!
TopicTable: aDictionary
	"Sets the dictionary with all topics."

	TopicTable :=  aDictionary! !

!System methodsFor: 'accessing' stamp: 'RFG 5/3/2013 20:17'!
UserTable
	"Returns the dictionary with all users."

	^UserTable.! !

!System methodsFor: 'accessing' stamp: 'RFG 5/3/2013 20:13'!
UserTable: aDictionary
	"Sets the system user table."

	UserTable := aDictionary.! !

!System methodsFor: 'init' stamp: 'RFG 5/3/2013 16:52'!
new
	"Creates and initializes the system."
	
	TopicTable isNil
		ifTrue: [TopicTable := Dictionary new].
	UserTable isNil
		ifTrue: [UserTable := Dictionary new].

	^self! !

Object subclass: #Topic
	instanceVariableNames: 'id name creator courseTable subjectTable moderatorList'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Project'!

!Topic commentStamp: 'RFG 5/2/2013 13:44' prior: 0!
Represents a topic in the system.!

!Topic class methodsFor: 'initialization' stamp: 'RFG 5/5/2013 09:23'!
newNamed: aName withID: anID creator: anUserID
	"Creates a new topic with the given name and id."
	
	|newTopic|
	
	newTopic := self new.
	
	newTopic id: anID.
	newTopic name: aName.
	newTopic creator: anUserID.
	
	newTopic courseTable isNil
		ifTrue: [newTopic courseTable: Dictionary new].
		
	newTopic subjectTable isNil
		ifTrue: [newTopic subjectTable: Dictionary new].
	
	newTopic moderatorList isNil
		ifTrue: [newTopic moderatorList: OrderedCollection new].! !

!Topic methodsFor: 'accessing' stamp: 'RFG 5/4/2013 11:16'!
courseTable
	"Returns the dictionary of courses of the topic."

	^courseTable.! !

!Topic methodsFor: 'accessing' stamp: 'RFG 5/4/2013 11:17'!
courseTable: aDictionary
	"Sets the dictionary of courses of the topic."

	courseTable := aDictionary.! !

!Topic methodsFor: 'accessing' stamp: 'RFG 5/5/2013 08:50'!
creator
	"Returns the topic creator."

	^creator.! !

!Topic methodsFor: 'accessing' stamp: 'RFG 5/5/2013 08:49'!
creator: anUserID.
	"Sets the topic creator."

	creator := anUserID.! !

!Topic methodsFor: 'accessing' stamp: 'RFG 5/4/2013 11:12'!
id
	"Returns the topic id."

	^id.! !

!Topic methodsFor: 'accessing' stamp: 'RFG 5/4/2013 11:12'!
id: anID
	"Sets the topic id."

	id := anID.! !

!Topic methodsFor: 'accessing' stamp: 'RFG 5/4/2013 15:44'!
moderatorList
	"Returns the list of moderators of the topic."

	^moderatorList.! !

!Topic methodsFor: 'accessing' stamp: 'RFG 5/4/2013 15:43'!
moderatorList: anOrderedCollection
	"Sets the list of moderators of the topic."

	moderatorList := anOrderedCollection.! !

!Topic methodsFor: 'accessing' stamp: 'RFG 5/4/2013 11:15'!
name
	"Returns the topic name."

	^name.! !

!Topic methodsFor: 'accessing' stamp: 'RFG 5/4/2013 11:15'!
name: aName.
	"Sets the topic name."

	name := aName.! !

!Topic methodsFor: 'accessing' stamp: 'RFG 5/4/2013 15:42'!
subjectTable
	"Returns the dictionary of subjects of the topic."

	^subjectTable.! !

!Topic methodsFor: 'accessing' stamp: 'RFG 5/4/2013 15:41'!
subjectTable: aDictionary
	"Sets the dictionary of subjects of the topic."

	subjectTable := aDictionary.! !

Object subclass: #User
	instanceVariableNames: 'id name courseList groupList contentList'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Project'!

!User commentStamp: 'RFG 5/2/2013 11:22' prior: 0!
Represents a user in the system.!

!User class methodsFor: 'construction' stamp: 'RFG 5/3/2013 18:20'!
id: anID name: aName
	"comment stating purpose of message"

	|newUser|
	newUser := self new.
	newUser id: anID.
	newUser name: aName.
	newUser groupList isNil
		ifTrue: [newUser groupList: OrderedCollection new].
	newUser courseList isNil
		ifTrue: [newUser courseList: OrderedCollection new].
	newUser contentList isNil
		ifTrue: [newUser contentList: OrderedCollection new].
	^newUser! !

!User methodsFor: 'getters' stamp: 'RFG 5/3/2013 16:31'!
contentList
	"Returns a list with the IDs of the Contents owned by the user."

	^contentList.! !

!User methodsFor: 'setters' stamp: 'RFG 5/3/2013 18:15'!
contentList: anOrderedCollection
	"Sets the user content list."

	contentList := anOrderedCollection.! !

!User methodsFor: 'getters' stamp: 'RFG 5/3/2013 16:39'!
courseList
	"comment stating purpose of message"

	^courseList.! !

!User methodsFor: 'setters' stamp: 'RFG 5/3/2013 18:19'!
courseList: anOrderedCollection
	"Sets the user content list."

	courseList := anOrderedCollection.! !

!User methodsFor: 'remotion' stamp: 'RFG 5/3/2013 18:52'!
delete.
	"Removes the user from the system."! !

!User methodsFor: 'subscription' stamp: 'RFG 5/3/2013 16:49'!
enrollCourse: courseID
	"Enrolls the user in a course."

	courseList add: courseID.! !

!User methodsFor: 'subscription' stamp: 'RFG 5/3/2013 16:50'!
enterGroup: aGroupID
	"Makes the user part of the group with the given ID."! !

!User methodsFor: 'getters' stamp: 'RFG 5/3/2013 16:30'!
groupList
	"Returns a list with the IDs of the Groups which the user is in."

	^groupList.! !

!User methodsFor: 'setters' stamp: 'RFG 5/3/2013 18:16'!
groupList: anOrderedCollection
	"Sets the user group list."

	groupList := anOrderedCollection.! !

!User methodsFor: 'getters' stamp: 'RFG 5/3/2013 15:32'!
id
	"Returns the user ID."

	^id.! !

!User methodsFor: 'setters' stamp: 'RFG 5/3/2013 15:17'!
id: anID
	"comment stating purpose of message"

	id := anID.! !

!User methodsFor: 'getters' stamp: 'RFG 5/3/2013 15:32'!
name
	"Returns the user's name."

	^name.! !

!User methodsFor: 'setters' stamp: 'RFG 5/3/2013 15:17'!
name: aName
	"comment stating purpose of message"

	name := aName.! !
